import { IRequestCommonOptions } from 'module/libs';
import { Groups, IMetaObject, IMetaPackage } from '../../types';
export interface IMaterialType {
    title: string;
    code: MaterialType;
}
export declare enum MaterialTerminal {
    pc = "pc",
    mobile = "mobile"
}
export declare type MaterialType = 'page' | 'block' | 'component' | 'api' | 'model' | 'orch' | 'icon' | 'theme';
export interface IMaterialExt {
    id: string;
    fullPath?: string;
    name: string;
    tags?: string[];
    author: string;
    type: MaterialType;
    terminal: MaterialTerminal;
    isOfficial?: boolean;
    icon?: string;
    snapshot?: string[];
    description: string;
    latestVersion: string;
    latestVersionId: string;
    installed?: boolean;
    installedVersion?: string;
    data?: any;
    createdBy?: string;
    createdByName?: string;
    createdAt?: string;
    updatedBy?: string;
    updatedByName?: string;
    updatedAt?: string;
}
export interface IMaterialExtDetail extends IMaterialExt {
    countUsed?: number;
}
export interface IInstalledMaterialExt {
    id: string;
    name: string;
    author: string;
    version: string;
    versionId: string;
    installedTime: string;
    marketUrl: string;
    detail?: IMaterialExt;
}
export declare function getMaterialTypes(url?: string): Promise<IMaterialType[]>;
export interface IQueryMaterialListParams {
    url?: string;
    type: MaterialType;
    isInstalled?: boolean;
    teamUrl?: string;
    platform?: MaterialTerminal;
    isOfficial?: boolean | 0 | 1 | 2;
}
export declare function queryMaterialList(params: IQueryMaterialListParams): Promise<IMaterialExt[]>;
export declare function findMaterialItem(id: string): Promise<IMaterialExtDetail>;
export declare function queryInstalledMaterialList(): Promise<IInstalledMaterialExt[]>;
/**
 * 安装物料包
 * @param url
 * @param id
 * @param versionId
 */
export declare function installMaterial(versionId: string): Promise<void>;
/**
 * 安装本地物料包
 */
export declare function installLocalMaterial(file: File): Promise<void>;
/**
 * 卸载物料包
 * @param id
 */
export declare function uninstallMaterial(id: string): Promise<void>;
/**
 * 查询物料市场物料包列表
 */
export declare function queryMarketPackages(group: Groups, id: string, options?: IRequestCommonOptions): Promise<IMetaPackage>;
/**
 * 获取物料市场某个物料包下面的某个资源的内容
 */
export declare function getMarketObject(group: Groups, id: string, versionId: string, options?: IRequestCommonOptions): Promise<IMetaObject>;
export interface IComponentPack {
    title: string;
    name: string;
    moduleName?: string;
    marketUrl: string;
    jsUrl?: string;
    cssUrl?: string;
    versionId: string;
    icon?: string;
    installed: boolean;
    tags: string[];
    schema: any;
}
/**
 * 获取物料市场组件包列表
 */
export declare function getMarketComponentPacks(options?: IRequestCommonOptions): Promise<IComponentPack[]>;
/**
 * 获取物料市场某个组件包的内容
 */
export declare function getMarketComponentPack(id: string, options?: IRequestCommonOptions): Promise<IComponentPack>;
/**
 * 记录物料包使用次数
 * @param id
 */
export declare function countUsage(versionId: string): Promise<void>;
/**
 * 检验团队物料并获取title
 */
export declare function getTeam(url: string): Promise<any>;
