import { HttpMethod } from './server-meta';
export interface IApi {
    paths: {
        [path: string]: Partial<Record<HttpMethod, IApiPathDetail>>;
    };
}
export interface IApiPathDetail {
    'x-impl': IApiXImplNormal | IApiXImplOrch | IApiXImplEntity | IApiXImplSql;
    'x-desc'?: string;
    summary?: string;
    operationId: string;
    tags?: string[];
    security?: IApiSecurity[];
    parameters?: IApiParameter[];
    requestBody?: IApiRequestBody;
    responses?: IApiResponses;
}
export interface IApiRequestBody {
    content?: {
        'application/json'?: {
            schema: {
                $ref?: string;
                type: 'object' | 'array';
            };
        };
    };
    description?: string;
    required?: boolean;
}
export interface IApiXImplNormal {
    auth: IXImplAuth;
}
export interface IApiXImplSql {
    type: 'sql';
    params: {
        content: string;
    };
    auth: IXImplAuth;
}
export interface IApiXImplOrch {
    type: 'function-flow';
    params: {
        name: string;
    };
    auth: IXImplAuth;
}
export interface IApiXImplEntity {
    type: 'entity';
    params: {
        entity: string;
        crud: 'create' | 'read' | 'update' | 'delete';
    };
    auth: IXImplAuth;
}
export interface IXImplAuth {
    enabled?: boolean;
    scopes?: string[];
    expr?: string;
}
export interface IApiSecurity {
    user: any[];
}
export interface IApiParameter {
    name: string;
    in: 'path' | 'query' | 'header' | 'cookie';
    required?: boolean;
    schema: {
        type: string;
    };
}
export interface IApiResponses {
    [httpCode: string]: IApiResponse;
}
export interface IApiResponse {
    description?: string;
}
